/*
 *   Copyright (C) 2007 Petri Damsten <damu@iki.fi>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU Library General Public License as
 *   published by the Free Software Foundation; either version 2, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details
 *
 *   You should have received a copy of the GNU Library General Public
 *   License along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef SVGWIDGET_HEADER
#define SVGWIDGET_HEADER

#include <plasma/plasma_export.h>
#include <plasma/widgets/widget.h>

namespace Plasma
{

/**
 * This class provides generic svg widget for the Plasma desktop.
 *
 * Besides showing plain svg it can also act as a meter. Currently analog and
 * bar meters are supported.
 *
 * @author Petri Damstén
 */

class PLASMA_EXPORT SvgWidget : public Plasma::Widget
{
    Q_OBJECT

public:
    /**
     * This enum SvgWidget modes
     */
    enum Mode
    {
        /** Plain svg. */
        PlainSvg,
        /** Bar meter (like thermometer). */
        BarMeter,
        /** Analog meter (like speed meter). */
        AnalogMeter
    };

    Q_PROPERTY(int minimum READ minimum WRITE setMinimum)
    Q_PROPERTY(int maximum READ maximum WRITE setMaximum)
    Q_PROPERTY(int value READ value WRITE setValue)
    Q_PROPERTY(QString format READ format WRITE setFormat)
    Q_PROPERTY(QString svg READ svg WRITE setSvg)
    Q_PROPERTY(Mode mode READ mode WRITE setMode)

public:
    /**
     * Constructor
     * @param parent the QGraphicsItem this icon is parented to.
     */
    SvgWidget(QGraphicsItem *parent = 0);

    /**
     * Destructor
     */
    virtual ~SvgWidget();

    /**
     * Set maximum value for the meter
     */
    void setMaximum(int maximum);

    /**
     * @return maximum value for the meter
     */
    int maximum() const;

    /**
     * Set minimum value for the meter
     */
    void setMinimum(int minimum);

    /**
     * @return minimum value for the meter
     */
    int minimum() const;

    /**
     * Set value for the meter
     */
    void setValue(int value);

    /**
     * @return value for the meter
     */
    int value() const;

    /**
     * Set text format for the meter
     */
    void setFormat(const QString& format);

    /**
     * @return text format for the meter
     */
    QString format() const;

    /**
     * Set svg file name
     */
    void setSvg(QString svg);

    /**
     * @return svg file name
     */
    QString svg() const;

    /**
     * Set svg widget mode
     */
    void setMode(Mode mode);

    /**
     * @return svg widget mode
     */
    Mode mode() const;

    /**
     * Reimplemented from Plasma::Widget
     */
    virtual QSizeF sizeHint() const;

protected:
    /**
     * Reimplemented from Plasma::Widget
     */
    virtual void paintWidget(QPainter *p,
                             const QStyleOptionGraphicsItem *option,
                             QWidget *widget = 0);

private:
    class Private;
    Private *const d;
};

} // End of namepace

#endif
